@@ -38,34 +38,30 @@
 //! }
 //! ```
 
-use crate::server::http_server::{HttpServer, NoopAcceptor};
-use crate::server::{Accept, Handle, MakeParts};
-
-use std::io;
-use std::pin::Pin;
-use std::sync::atomic::{AtomicUsize, Ordering};
-use std::sync::Arc;
-use std::task::{Context, Poll};
-
-use tokio::io::{AsyncRead, AsyncWrite, ReadBuf};
-
+use crate::server::{
+    http_server::{HttpServer, NoopAcceptor},
+    Accept, Handle, MakeParts,
+};
 use http::uri::Scheme;
-
+use std::{
+    io,
+    pin::Pin,
+    sync::{
+        atomic::{AtomicUsize, Ordering},
+        Arc,
+    },
+    task::{Context, Poll},
+};
+use tokio::io::{AsyncRead, AsyncWrite, ReadBuf};
 use tower_http::add_extension::AddExtension;
 use tower_layer::Layer;
 
 /// Type to access data that is being recorded in real-time.
-#[derive(Default, Clone)]
+#[derive(Clone, Debug, Default)]
 pub struct Recording {
     inner: Arc<RecordingInner>,
 }
 
-#[derive(Default)]
-struct RecordingInner {
-    sent: AtomicUsize,
-    received: AtomicUsize,
-}
-
 impl Recording {
     /// Get recorded outgoing bytes.
     ///
@@ -82,6 +78,12 @@ impl Recording {
     }
 }
 
+#[derive(Debug, Default)]
+struct RecordingInner {
+    sent: AtomicUsize,
+    received: AtomicUsize,
+}
+
 #[cfg(feature = "tls-rustls")]
 impl<S, A> HttpServer<S, MakeRecordingParts<A>> {
     pub(crate) fn recording_new(scheme: Scheme, service: S, handle: Handle, acceptor: A) -> Self {
@@ -235,15 +237,17 @@ where
 #[cfg(test)]
 mod tests {
     use super::Recording;
-
-    use crate::server::tests::{empty_request, http_client, into_text};
-    use crate::{Handle, Server};
-
+    use crate::{
+        server::tests::{empty_request, http_client, into_text},
+        Handle, Server,
+    };
     use axum::{extract::Extension, handler::get};
     use tower_service::Service;
     use tower_util::ServiceExt;
 
-    #[ignore]
+    #[cfg(feature = "tls-rustls")]
+    use crate::server::tls::tests::{https_client, CERTIFICATE, PRIVATE_KEY};
+
     #[tokio::test]
     async fn test_record() {
         let app = get(handler);
@@ -273,10 +277,6 @@ mod tests {
         }
     }
 
-    #[cfg(feature = "tls-rustls")]
-    use crate::server::tls::tests::{https_client, CERTIFICATE, PRIVATE_KEY};
-
-    #[ignore]
     #[tokio::test]
     #[cfg(feature = "tls-rustls")]
     async fn test_tls_record() {
